# 0.2.0

* Reduction in size of code, removal of old garbage

# 0.1.10

* Increased pinned napari (0.4.12) version Tensorflow version (2.7.0) - hopefully this fixes `typing_extensions` intercompatibility issues.
* Default values for `phase_contrast_drawing.generate_test_comparison` give a reasonable starting point for manual image optimisation.
* Added phase contrast drawing tests
* Added this changelog
# 0.1.9

* Bumped Tensorflow version to 2.5.2.

# 0.1.6

* Lowered Tensorflow version to 2.5.2 for DeLTA compatibility.

# 0.1.4

* Added sample TIFF images for example notebook.

# 0.1.3

* Removed `csbdeep` and `stardist` as dependencies. Install as necessary.